@@ -9,6 +9,7 @@
 #'
 #' @return An `"eps"` file
 #'
+#' @import grDevices
 #' @export
 #' @family save
 #'
@@ -37,7 +38,8 @@ save_eps <- function(gplot, file.name,  ...){
     warning("O formato do arquivo deve ser '.eps'")
   }
 
-  ggplot2::ggsave(gplot, file = file.name,  device="eps", family = 'Frutiger LT Light Cond', ...)
+ ggplot2::ggsave(gplot, file = file.name,  device=cairo_ps, ...)
+
 
 
 }
